pub struct GeometryAttribute { /* private fields */ }Expand description
Format descriptor shared by point and mesh attributes.
Implementations
Sourceimpl GeometryAttribute
impl GeometryAttribute
Sourcepub fn init(
&mut self,
attribute_type: GeometryAttributeType,
_buffer: Option<&DataBuffer>,
num_components: u8,
data_type: DataType,
normalized: bool,
byte_stride: i64,
byte_offset: i64,
)
pub fn init( &mut self, attribute_type: GeometryAttributeType, _buffer: Option<&DataBuffer>, num_components: u8, data_type: DataType, normalized: bool, byte_stride: i64, byte_offset: i64, )
Initializes the attribute format descriptor.
Sourcepub fn attribute_type(&self) -> GeometryAttributeType
pub fn attribute_type(&self) -> GeometryAttributeType
Returns the semantic attribute type.
Sourcepub fn num_components(&self) -> u8
pub fn num_components(&self) -> u8
Returns the number of scalar components per attribute value.
Sourcepub fn normalized(&self) -> bool
pub fn normalized(&self) -> bool
Returns whether integer data should be interpreted as normalized.
Sourcepub fn byte_stride(&self) -> i64
pub fn byte_stride(&self) -> i64
Returns the byte stride between consecutive values.
Sourcepub fn byte_offset(&self) -> i64
pub fn byte_offset(&self) -> i64
Returns the byte offset of the first value.
Sourcepub fn set_unique_id(&mut self, id: u32)
pub fn set_unique_id(&mut self, id: u32)
Sets the stable Draco unique id for this attribute.
Sourcepub fn set_attribute_type(&mut self, attribute_type: GeometryAttributeType)
pub fn set_attribute_type(&mut self, attribute_type: GeometryAttributeType)
Sets the semantic attribute type.
Sourcepub fn set_data_type(&mut self, data_type: DataType)
pub fn set_data_type(&mut self, data_type: DataType)
Sets the scalar data type.
Sourcepub fn set_num_components(&mut self, num_components: u8)
pub fn set_num_components(&mut self, num_components: u8)
Sets the number of scalar components per value.