GeometryMetadata

Struct GeometryMetadata 

pub struct GeometryMetadata { /* private fields */ }
Geometry-level metadata plus per-attribute metadata.

Implementations

Source

impl GeometryMetadata

pub fn new() -> Self

Creates empty geometry metadata.

pub fn is_empty(&self) -> bool

Returns true when no geometry or attribute metadata is present.

pub fn metadata(&self) -> &Metadata

Returns geometry-level metadata.

pub fn metadata_mut(&mut self) -> &mut Metadata

Returns mutable geometry-level metadata.

pub fn attribute_metadata(&self) -> &[AttributeMetadata]

Returns all per-attribute metadata blocks.

pub fn attribute_metadata_by_unique_id( &self, attribute_unique_id: u32, ) -> Option<&AttributeMetadata>

Finds per-attribute metadata by Draco attribute unique id.

pub fn attribute_metadata_by_string_entry( &self, entry_name: &str, entry_value: &str, ) -> Option<&AttributeMetadata>

Finds per-attribute metadata by a string metadata entry.

pub fn attribute_metadata_by_unique_id_mut( &mut self, attribute_unique_id: u32, ) -> Option<&mut AttributeMetadata>

Finds mutable per-attribute metadata by Draco attribute unique id.

pub fn set_attribute_metadata( &mut self, attribute_unique_id: u32, metadata: Metadata, )

Inserts or replaces metadata for one Draco attribute unique id.

pub fn decode(buffer: &mut DecoderBuffer<'_>) -> Result<Self, DracoError>

Available on crate feature decoder only.

Decodes geometry metadata from a Draco bitstream buffer.

pub fn encode(&self, buffer: &mut EncoderBuffer) -> Result<(), DracoError>

Available on crate feature encoder only.

Encodes geometry metadata to a Draco bitstream buffer.