Module point_cloud_encoder

Module point_cloud_encoder 

Available on crate feature encoder only.
Point cloud encoder entry point.

Structs

EncodedPointCloudInfo
Encoder choices and attribute metadata from a successful point-cloud encode.
PointCloudEncoder
Encoder for Draco point cloud bitstreams.

Traits

GeometryEncoder
Geometry context used by attribute encoders and prediction selection.