GeometryEncoder

Trait GeometryEncoder 

pub trait GeometryEncoder {
    // Required methods
    fn point_cloud(&self) -> Option<&PointCloud>;
    fn mesh(&self) -> Option<&Mesh>;
    fn corner_table(&self) -> Option<&CornerTable>;
    fn options(&self) -> &EncoderOptions;
    fn get_geometry_type(&self) -> EncodedGeometryType;

    // Provided methods
    fn get_encoding_method(&self) -> Option<i32> { ... }
    fn get_data_to_corner_map(&self) -> Option<&[u32]> { ... }
    fn get_vertex_to_data_map(&self) -> Option<&[i32]> { ... }
}
Available on crate feature encoder only.
Geometry context used by attribute encoders and prediction selection.

Required Methods

fn point_cloud(&self) -> Option<&PointCloud>

Returns point-cloud geometry when available.

fn mesh(&self) -> Option<&Mesh>

Returns mesh geometry when available.

fn corner_table(&self) -> Option<&CornerTable>

Returns mesh corner-table topology when available.

fn options(&self) -> &EncoderOptions

Returns the active encoder options.

fn get_geometry_type(&self) -> EncodedGeometryType

Returns the encoded geometry type.

Provided Methods

fn get_encoding_method(&self) -> Option<i32>

Returns the forced encoding method, if one is active.

fn get_data_to_corner_map(&self) -> Option<&[u32]>

Returns a data-to-corner map for mesh attribute prediction, if present.

fn get_vertex_to_data_map(&self) -> Option<&[i32]>

Returns a vertex-to-data map for mesh attribute prediction, if present.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors