Module status

Module status 

Error and status types.

Enums

DracoError
Error returned by Draco decoding, encoding, and data model operations.

Functions

error_status
Creates a generic DracoError from a message.
ok_status
Returns a successful Status.

Type Aliases

Status
Convenience result type for operations that only report success or failure.