PointAttribute

Struct PointAttribute 

pub struct PointAttribute { /* private fields */ }
Typed attribute values attached to points in a point cloud or mesh.

Attribute data is stored in a contiguous byte buffer. Point ids either map directly to attribute value ids, or through an explicit point-to-value map when multiple points share or reorder attribute entries.

Implementations

Source

impl PointAttribute

pub fn new() -> Self

Creates an empty attribute with an invalid semantic type.

pub fn init( &mut self, attribute_type: GeometryAttributeType, num_components: u8, data_type: DataType, normalized: bool, num_attribute_values: usize, )

Initializes the attribute and allocates storage for its values.

pub fn try_init( &mut self, attribute_type: GeometryAttributeType, num_components: u8, data_type: DataType, normalized: bool, num_attribute_values: usize, ) -> Result<(), DracoError>

Fallibly initializes the attribute and allocates storage for its values.

pub fn mapped_index(&self, point_index: PointIndex) -> AttributeValueIndex

Maps a point id to the corresponding attribute value id.

pub fn size(&self) -> usize

Returns the number of unique attribute values.

pub fn resize_unique_entries( &mut self, num_attribute_values: usize, ) -> Result<(), DracoError>

Resizes the unique attribute value storage.

pub fn buffer(&self) -> &DataBuffer

Returns the raw attribute value buffer.

pub fn buffer_mut(&mut self) -> &mut DataBuffer

Returns the mutable raw attribute value buffer.

pub fn attribute_type(&self) -> GeometryAttributeType

Returns the semantic attribute type.

pub fn unique_id(&self) -> u32

Returns the stable Draco unique id.

pub fn set_unique_id(&mut self, id: u32)

Sets the stable Draco unique id.

pub fn set_attribute_type(&mut self, attribute_type: GeometryAttributeType)

Sets the semantic attribute type.

pub fn set_data_type(&mut self, data_type: DataType)

Sets the scalar data type.

pub fn set_num_components(&mut self, num_components: u8)

Sets the number of scalar components per value.

pub fn set_identity_mapping(&mut self)

Uses point ids directly as attribute value ids.

pub fn set_explicit_mapping(&mut self, num_points: usize)

Allocates an explicit point-to-attribute-value map.

pub fn set_point_map_entry( &mut self, point_index: PointIndex, entry_index: AttributeValueIndex, )

Sets one point-to-attribute-value map entry.

pub fn try_set_point_map_entry( &mut self, point_index: PointIndex, entry_index: AttributeValueIndex, ) -> Result<(), DracoError>

Fallibly sets one point-to-attribute-value map entry.

pub fn set_attribute_transform_data(&mut self, data: AttributeTransformData)

Stores transform metadata associated with this attribute.

pub fn attribute_transform_data(&self) -> Option<&AttributeTransformData>

Returns transform metadata associated with this attribute, if present.

pub fn data_type(&self) -> DataType

Returns the scalar data type.

pub fn normalized(&self) -> bool

Returns whether integer data should be interpreted as normalized.

pub fn num_components(&self) -> u8

Returns the number of scalar components per value.

pub fn byte_stride(&self) -> i64

Returns the byte stride between consecutive values.