pub trait GeometryEncoder {
// Required methods
fn point_cloud(&self) -> Option<&PointCloud>;
fn mesh(&self) -> Option<&Mesh>;
fn corner_table(&self) -> Option<&CornerTable>;
fn options(&self) -> &EncoderOptions;
fn get_geometry_type(&self) -> EncodedGeometryType;
// Provided methods
fn get_encoding_method(&self) -> Option<i32> { ... }
fn get_data_to_corner_map(&self) -> Option<&[u32]> { ... }
fn get_vertex_to_data_map(&self) -> Option<&[i32]> { ... }
}Available on crate feature
encoder only.Expand description
Geometry context used by attribute encoders and prediction selection.
Required Methods
Sourcefn point_cloud(&self) -> Option<&PointCloud>
fn point_cloud(&self) -> Option<&PointCloud>
Returns point-cloud geometry when available.
Sourcefn corner_table(&self) -> Option<&CornerTable>
fn corner_table(&self) -> Option<&CornerTable>
Returns mesh corner-table topology when available.
Sourcefn options(&self) -> &EncoderOptions
fn options(&self) -> &EncoderOptions
Returns the active encoder options.
Sourcefn get_geometry_type(&self) -> EncodedGeometryType
fn get_geometry_type(&self) -> EncodedGeometryType
Returns the encoded geometry type.
Provided Methods
Sourcefn get_encoding_method(&self) -> Option<i32>
fn get_encoding_method(&self) -> Option<i32>
Returns the forced encoding method, if one is active.
Sourcefn get_data_to_corner_map(&self) -> Option<&[u32]>
fn get_data_to_corner_map(&self) -> Option<&[u32]>
Returns a data-to-corner map for mesh attribute prediction, if present.
Sourcefn get_vertex_to_data_map(&self) -> Option<&[i32]>
fn get_vertex_to_data_map(&self) -> Option<&[i32]>
Returns a vertex-to-data map for mesh attribute prediction, if present.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".