Error and status types.
Structs
- Draco
Error - Error returned by Draco decoding, encoding, and data model operations.
Enums
- Error
Kind - What a
DracoErrorrefused, as a value that can be compared and copied.
Functions
- error_
status - Creates a generic
DracoErrorfrom a message. - ok_
status - Returns a successful
Status.
Type Aliases
- Status
- Convenience result type for operations that only report success or failure.